"""pylandstats init."""
from .landscape import *
from .spatiotemporal import *
from .zonal import *

__version__ = "2.4.2"
